fn validate_index_schema(schema: &SchemaRef) -> Result<TimeUnit>Expand description
Validates an index file’s schema and returns the time unit of its
__series_min_ts/__series_max_ts columns. They are native
Timestamp(unit) columns, so the unit is part of the datatype and each
file is interpreted in the unit it was written with.